## toc.myt - prints table of contents listings given toc.TOCElement strucures <%def name="toc(toc, paged, extension)">
<%def name="printtoc(root, paged, extension, current=None, children=True, anchor_toplevel=False)">

% for item in root.children:
- ${item.description}
% if children: ${printtoc(item, current=current, children=True,anchor_toplevel=True, paged=paged, extension=extension)} % endif % endfor